==> gs2-cdk-1.0.87.tar.gz: gs2-cdk-1.0.87/src/gs2_cdk/formation/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .FormModel import FormModel
from .options.FormModelOptions import FormModelOptions
from .MoldModel import MoldModel
from .options.MoldModelOptions import MoldModelOptions
from .PropertyFormModel import PropertyFormModel
from .options.PropertyFormModelOptions import PropertyFormModelOptions
from .Slot import Slot
from .options.SlotOptions import SlotOptions
from .SlotModel import SlotModel
from .options.SlotModelOptions import SlotModelOptions
from .SlotWithSignature import SlotWithSignature
from .options.SlotWithSignatureOptions import SlotWithSignatureOptions
from .enum.SlotWithSignaturePropertyType import SlotWithSignaturePropertyType
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.94.tar.gz: gs2-cdk-1.0.94/src/gs2_cdk/formation/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .FormModel import FormModel
from .options.FormModelOptions import FormModelOptions
from .MoldModel import MoldModel
from .options.MoldModelOptions import MoldModelOptions
from .PropertyFormModel import PropertyFormModel
from .options.PropertyFormModelOptions import PropertyFormModelOptions
from .Slot import Slot
from .options.SlotOptions import SlotOptions
from .SlotModel import SlotModel
from .options.SlotModelOptions import SlotModelOptions
from .SlotWithSignature import SlotWithSignature
from .options.SlotWithSignatureOptions import SlotWithSignatureOptions
from .enums.SlotWithSignaturePropertyType import SlotWithSignaturePropertyType
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData
